/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'format', 'bn', {
	label: 'ধরন-প্রকৃতি',
	panelTitle: 'ফন্ট ফরমেট',
	tag_address: 'ঠিকানা',
	tag_div: 'শীর্ষক (DIV)',
	tag_h1: 'শীর্ষক ১',
	tag_h2: 'শীর্ষক ২',
	tag_h3: 'শীর্ষক ৩',
	tag_h4: 'শীর্ষক ৪',
	tag_h5: 'শীর্ষক ৫',
	tag_h6: 'শীর্ষক ৬',
	tag_p: 'সাধারণ',
	tag_pre: 'ফর্মেটেড'
} );
